pub struct TenantRequest<'a> {
pub id: Uuid,
pub name: &'a str,
pub metadata: Value,
pub creator_name: Option<&'a str>,
pub creator_email: Option<&'a str>,
}Expand description
The subset of Tenant used in create requests.
Fields
id: UuidThe ID of the tenant.
name: &'a strThe name of the tenant.
metadata: ValueArbitrary metadata to attach to the tenant.
creator_name: Option<&'a str>The name of the person who created the tenant.
creator_email: Option<&'a str>The email of the person who created the tenant.